@@ -7,13 +7,25 @@
 # Use a try-except block to avoid import errors on build systems.
 try:
     from .contexts import AppManagerContext as App
-    from .models import *
+    from .models import (
+        ModelObject,
+        StringType,
+        IntegerType,
+        BooleanType,
+        FloatType,
+        ListType,
+        DictType,
+        ModelType,
+    )
     from .commands import *
-    from .contracts import *
-    from .data import *
+    from .contracts import (
+        ModelContract,
+        Repository
+    )
+    from .data import DataObject
     from .proxies import *
 except:
     pass
 
 # *** version
-__version__ = '1.1.3'
+__version__ = '1.1.13'
