@@ -1,3 +1,5 @@
+"""Tiferet App Contexts"""
+
 # *** imports
 
 # ** core
@@ -7,9 +9,12 @@ from typing import Dict, Any
 from .feature import FeatureContext
 from .error import ErrorContext
 from .logging import LoggingContext
+from .request import RequestContext
 from ..configs.app import DEFAULT_ATTRIBUTES
-from ..models.feature import Request
-from ..models.app import *
+from ..models import (
+    ModelObject,
+    AppAttribute,
+)
 from ..handlers.app import (
     AppService,
     AppHandler,
@@ -21,13 +26,13 @@ from ..commands import (
 )
 from ..commands.app import GetAppInterface
 
-
 # *** contexts
 
-# ** context: app_context
-class AppContext(object):
+# ** context: app_manager_context
+class AppManagerContext(object):
     '''
-    The application context is a class that is used to create and run the application instance.
+    The AppManagerContext is responsible for managing the application context.
+    It provides methods to load the application interface and run features.
     '''
 
     # * attribute: settings
@@ -36,19 +41,21 @@ class AppContext(object):
     # * attribute: app_service
     app_service: AppService
 
-    # * method: init
+    # * init
     def __init__(self, settings: Dict[str, Any] = {}, app_service: AppService = AppHandler()):
         '''
-        Initialize the application context.
-        
+        Initialize the AppManagerContext with an application service.
+
         :param settings: The application settings.
         :type settings: dict
-        :param app_service: The application service to use for executing app requests.
+        :param app_service: The application service to use.
         :type app_service: AppService
         '''
-        
-        # Assign the settings and app service.
+
+        # Set the settings.
         self.settings = settings
+
+        # Set the app service.
         self.app_service = app_service
 
     # * method: load_interface
@@ -80,7 +87,7 @@ class AppContext(object):
             **attr_data,
             validate=False
         ) for attr_data in DEFAULT_ATTRIBUTES]
-        
+
         # Create the app interface context.
         app_interface_context = self.app_service.load_app_instance(app_interface, default_attrs=default_attrs)
 
@@ -91,7 +98,7 @@ class AppContext(object):
                 f'App context for interface is not valid: {interface_id}.',
                 interface_id
             )
-        
+
         # Return the app interface context.
         return app_interface_context
 
@@ -129,7 +136,6 @@ class AppContext(object):
             **kwargs
         )
 
-
 # ** context: app_interface_context
 class AppInterfaceContext(object): 
     '''
@@ -148,7 +154,7 @@ class AppInterfaceContext(object):
     # * attribute: logging
     logging: LoggingContext
 
-    # * method: init
+    # * init
     def __init__(self, interface_id: str, features: FeatureContext, errors: ErrorContext, logging: LoggingContext):
         '''
         Initialize the application interface context.
@@ -168,7 +174,7 @@ class AppInterfaceContext(object):
         self.logging = logging
 
     # * method: parse_request
-    def parse_request(self, headers: Dict[str, str] = {}, data: Dict[str, Any] = {}) -> Request:
+    def parse_request(self, headers: Dict[str, str] = {}, data: Dict[str, Any] = {}, feature_id: str = None) -> RequestContext:
         '''
         Parse the incoming request.
 
@@ -176,8 +182,10 @@ class AppInterfaceContext(object):
         :type headers: dict
         :param data: The request data.
         :type data: dict
-        :return: The parsed request.
-        :rtype: Request
+        :param feature_id: The feature identifier if provided.
+        :type feature_id: str
+        :return: The parsed request as a request context.
+        :rtype: RequestContext
         '''
 
         # Add the interface id to the request headers.
@@ -185,25 +193,25 @@ class AppInterfaceContext(object):
             interface_id=self.interface_id,
         ))
 
-        # Create the request model object.
-        request = ModelObject.new(
-            Request,
+        # Create the request context object.
+        request = RequestContext(
             headers=headers,
             data=data,
+            feature_id=feature_id,
         )
 
         # Return the request model object.
         return request
-    
+
     # * method: execute_feature
-    def execute_feature(self, feature_id: str, request: Request, **kwargs):
+    def execute_feature(self, feature_id: str, request: RequestContext, **kwargs):
         '''
         Execute the feature context.
 
         :param feature_id: The feature identifier.
         :type feature_id: str
-        :param request: The request.
-        :type request: Request
+        :param request: The request context object.
+        :type request: RequestContext
         :param kwargs: Additional keyword arguments.
         :type kwargs: dict
         '''
@@ -239,7 +247,7 @@ class AppInterfaceContext(object):
         return self.errors.handle_error(error)
 
     # * method: handle_response
-    def handle_response(self, request: Request) -> Any:
+    def handle_response(self, request: RequestContext) -> Any:
         '''
         Handle the response from the request.
 
@@ -251,7 +259,7 @@ class AppInterfaceContext(object):
 
         # Handle the response and return it.
         return request.handle_response()
-    
+
     # * method: run
     def run(self, 
             feature_id: str, 
@@ -273,15 +281,15 @@ class AppInterfaceContext(object):
 
         # Create the logger for the app interface context.
         logger = self.logging.build_logger()
-        
+
         # Parse request.
         logger.debug(f'Parsing request for feature: {feature_id}')
-        request = self.parse_request(headers, data)
+        request = self.parse_request(headers, data, feature_id)
 
         # Execute feature context and return session.
         try:
             logger.info(f'Executing feature: {feature_id}')
-            logger.debug(f'Executing feature: {feature_id} with request: {request.to_primitive()}')
+            logger.debug(f'Executing feature: {feature_id} with request: {request.data}')
             self.execute_feature(
                 feature_id=feature_id, 
                 request=request, 
@@ -296,3 +304,14 @@ class AppInterfaceContext(object):
         # Handle response.
         logger.debug(f'Feature {feature_id} executed successfully, handling response.')
         return self.handle_response(request)
+
+# ** context: app_context (obsolete)
+class AppContext(AppManagerContext):
+    '''
+    The AppContext is an obsolete class that extends the AppManagerContext.
+    It is kept for backward compatibility but should not be used in new code.
+    '''
+
+    # * init
+    def __init__(self, settings: Dict[str, Any] = {}, app_service: AppService = AppHandler()):
+        super().__init__(settings, app_service)
