@@ -1,11 +1,20 @@
+"""Tiferet Error Data Transfer Objects"""
+
 # *** imports
 
 # ** app
-from ..configs import *
-from ..data import DataObject
-from ..models.error import *
-from ..contracts.error import Error as ErrorContract
-
+from ..models import (
+    Error,
+    ErrorMessage,
+    ListType,
+    ModelType,
+)
+from ..contracts import (
+    ErrorContract,
+)
+from .settings import (
+    DataObject,
+)
 
 # *** data
 
@@ -52,7 +61,6 @@ class ErrorData(Error, DataObject):
             ),
             message=[msg.to_primitive() for msg in self.message]
         ) 
-        
 
     # * method: map
     def map(self, **kwargs) -> ErrorContract:
@@ -86,4 +94,4 @@ class ErrorData(Error, DataObject):
         return super(ErrorData, ErrorData).from_data(
             ErrorData, 
             **kwargs
-        )
+        )
\ No newline at end of file
