@@ -1,13 +1,26 @@
+"""Tiferet Feature Data Objects"""
+
 # *** imports
 
 # ** infra
 from schematics.types.serializable import serializable
 
-# 
-from ..data import DataObject
-from ..contracts.feature import Feature as FeatureContract, FeatureCommand as FeatureCommandContract
-from ..models.feature import *
-
+# app
+from ..models import (
+    Feature,
+    FeatureCommand,
+    ListType,
+    ModelType,
+    DictType,
+    StringType,
+)
+from ..contracts import (
+    FeatureContract,
+    FeatureCommandContract,
+)
+from .settings import (
+    DataObject,
+)
 
 class FeatureCommandData(FeatureCommand, DataObject):
     '''
@@ -42,7 +55,7 @@ class FeatureCommandData(FeatureCommand, DataObject):
     def map(self, role: str = 'to_model', **kwargs) -> FeatureCommandContract:
         '''
         Maps the feature handler data to a feature handler object.
-        
+
         :param role: The role for the mapping.
         :type role: str
         :param kwargs: Additional keyword arguments.
@@ -55,7 +68,6 @@ class FeatureCommandData(FeatureCommand, DataObject):
             parameters=self.parameters,
             **kwargs)
 
-
 class FeatureData(Feature, DataObject):
     '''
     A data representation of a feature.
@@ -74,11 +86,13 @@ class FeatureData(Feature, DataObject):
             'to_model': DataObject.deny('feature_key'),
             'to_data': DataObject.deny('feature_key', 'group_id', 'id')
         }
-    
+
     # * attributes
-    commands = ListType(ModelType(FeatureCommandData),
-                          deserialize_from=['handlers', 'functions', 'commands'],)
-    
+    commands = ListType(
+        ModelType(FeatureCommandData),
+        deserialize_from=['handlers', 'functions', 'commands'],
+    )
+
     @serializable
     def feature_key(self):
         '''
@@ -113,7 +127,7 @@ class FeatureData(Feature, DataObject):
     def from_data(**kwargs) -> 'FeatureData':
         '''
         Initializes a new FeatureData object from a Feature object.
-        
+
         :param kwargs: Additional keyword arguments.
         :type kwargs: dict
         :return: A new FeatureData object.
@@ -125,3 +139,4 @@ class FeatureData(Feature, DataObject):
             FeatureData, 
             **kwargs
         )
+
